==> glfw-doc-3.2.1-1-armv6h.pkg.tar.xz: usr/share/doc/glfw/html/search/defines_0.js <==
var searchData=
[
  ['glfw_5faccum_5falpha_5fbits',['GLFW_ACCUM_ALPHA_BITS',['../glfw3_8h.html#ae829b55591c18169a40ab4067a041b1f',1,'glfw3.h']]],
  ['glfw_5faccum_5fblue_5fbits',['GLFW_ACCUM_BLUE_BITS',['../glfw3_8h.html#a22bbe9104a8ce1f8b88fb4f186aa36ce',1,'glfw3.h']]],
  ['glfw_5faccum_5fgreen_5fbits',['GLFW_ACCUM_GREEN_BITS',['../glfw3_8h.html#a65713cee1326f8e9d806fdf93187b471',1,'glfw3.h']]],
  ['glfw_5faccum_5fred_5fbits',['GLFW_ACCUM_RED_BITS',['../glfw3_8h.html#aead34a9a683b2bc20eecf30ba738bfc6',1,'glfw3.h']]],
  ['glfw_5falpha_5fbits',['GLFW_ALPHA_BITS',['../glfw3_8h.html#afed79a3f468997877da86c449bd43e8c',1,'glfw3.h']]],
  ['glfw_5fany_5frelease_5fbehavior',['GLFW_ANY_RELEASE_BEHAVIOR',['../glfw3_8h.html#a6b47d806f285efe9bfd7aeec667297ee',1,'glfw3.h']]],
  ['glfw_5fauto_5ficonify',['GLFW_AUTO_ICONIFY',['../glfw3_8h.html#a9d9874fc928200136a6dcdad726aa252',1,'glfw3.h']]],
  ['glfw_5faux_5fbuffers',['GLFW_AUX_BUFFERS',['../glfw3_8h.html#ab05108c5029443b371112b031d1fa174',1,'glfw3.h']]],
  ['glfw_5fblue_5fbits',['GLFW_BLUE_BITS',['../glfw3_8h.html#ab292ea403db6d514537b515311bf9ae3',1,'glfw3.h']]],
  ['glfw_5fclient_5fapi',['GLFW_CLIENT_API',['../glfw3_8h.html#a649309cf72a3d3de5b1348ca7936c95b',1,'glfw3.h']]],
  ['glfw_5fconnected',['GLFW_CONNECTED',['../glfw3_8h.html#abe11513fd1ffbee5bb9b173f06028b9e',1,'glfw3.h']]],
  ['glfw_5fcontext_5fcreation_5fapi',['GLFW_CONTEXT_CREATION_API',['../glfw3_8h.html#a5154cebfcd831c1cc63a4d5ac9bb4486',1,'glfw3.h']]],
  ['glfw_5fcontext_5fno_5ferror',['GLFW_CONTEXT_NO_ERROR',['../glfw3_8h.html#a5a52fdfd46d8249c211f923675728082',1,'glfw3.h']]],
  ['glfw_5fcontext_5frelease_5fbehavior',['GLFW_CONTEXT_RELEASE_BEHAVIOR',['../glfw3_8h.html#a72b648a8378fe3310c7c7bbecc0f7be6',1,'glfw3.h']]],
  ['glfw_5fcontext_5frevision',['GLFW_CONTEXT_REVISION',['../glfw3_8h.html#afb9475071aa77c6fb05ca5a5c8678a08',1,'glfw3.h']]],
  ['glfw_5fcontext_5frobustness',['GLFW_CONTEXT_ROBUSTNESS',['../glfw3_8h.html#ade3593916b4c507900aa2d6844810e00',1,'glfw3.h']]],
  ['glfw_5fcontext_5fversion_5fmajor',['GLFW_CONTEXT_VERSION_MAJOR',['../glfw3_8h.html#afe5e4922de1f9932d7e9849bb053b0c0',1,'glfw3.h']]],
  ['glfw_5fcontext_5fversion_5fminor',['GLFW_CONTEXT_VERSION_MINOR',['../glfw3_8h.html#a31aca791e4b538c4e4a771eb95cc2d07',1,'glfw3.h']]],
  ['glfw_5fcursor',['GLFW_CURSOR',['../glfw3_8h.html#aade31da5b884a84a7625c6b059b9132c',1,'glfw3.h']]],
  ['glfw_5fcursor_5fdisabled',['GLFW_CURSOR_DISABLED',['../glfw3_8h.html#a2315b99a329ce53e6a13a9d46fd5ca88',1,'glfw3.h']]],
  ['glfw_5fcursor_5fhidden',['GLFW_CURSOR_HIDDEN',['../glfw3_8h.html#ac4d5cb9d78de8573349c58763d53bf11',1,'glfw3.h']]],
  ['glfw_5fcursor_5fnormal',['GLFW_CURSOR_NORMAL',['../glfw3_8h.html#ae04dd25c8577e19fa8c97368561f6c68',1,'glfw3.h']]],
  ['glfw_5fdecorated',['GLFW_DECORATED',['../glfw3_8h.html#a21b854d36314c94d65aed84405b2f25e',1,'glfw3.h']]],
  ['glfw_5fdepth_5fbits',['GLFW_DEPTH_BITS',['../glfw3_8h.html#a318a55eac1fee57dfe593b6d38149d07',1,'glfw3.h']]],
  ['glfw_5fdisconnected',['GLFW_DISCONNECTED',['../glfw3_8h.html#aab64b25921ef21d89252d6f0a71bfc32',1,'glfw3.h']]],
  ['glfw_5fdont_5fcare',['GLFW_DONT_CARE',['../glfw3_8h.html#a7a2edf2c18446833d27d07f1b7f3d571',1,'glfw3.h']]],
  ['glfw_5fdoublebuffer',['GLFW_DOUBLEBUFFER',['../glfw3_8h.html#a714a5d569e8a274ea58fdfa020955339',1,'glfw3.h']]],
  ['glfw_5fegl_5fcontext_5fapi',['GLFW_EGL_CONTEXT_API',['../glfw3_8h.html#a03cf65c9ab01fc8b872ba58842c531c9',1,'glfw3.h']]],
  ['glfw_5ffalse',['GLFW_FALSE',['../glfw3_8h.html#ac877fe3b627d21ef3a0a23e0a73ba8c5',1,'glfw3.h']]],
  ['glfw_5ffloating',['GLFW_FLOATING',['../glfw3_8h.html#a7fb0be51407783b41adbf5bec0b09d80',1,'glfw3.h']]],
  ['glfw_5ffocused',['GLFW_FOCUSED',['../glfw3_8h.html#a54ddb14825a1541a56e22afb5f832a9e',1,'glfw3.h']]],
  ['glfw_5fgreen_5fbits',['GLFW_GREEN_BITS',['../glfw3_8h.html#afba3b72638c914e5fb8a237dd4c50d4d',1,'glfw3.h']]],
  ['glfw_5ficonified',['GLFW_ICONIFIED',['../glfw3_8h.html#a39d44b7c056e55e581355a92d240b58a',1,'glfw3.h']]],
  ['glfw_5flose_5fcontext_5fon_5freset',['GLFW_LOSE_CONTEXT_ON_RESET',['../glfw3_8h.html#aec1132f245143fc915b2f0995228564c',1,'glfw3.h']]],
  ['glfw_5fmaximized',['GLFW_MAXIMIZED',['../glfw3_8h.html#ad8ccb396253ad0b72c6d4c917eb38a03',1,'glfw3.h']]],
  ['glfw_5fnative_5fcontext_5fapi',['GLFW_NATIVE_CONTEXT_API',['../glfw3_8h.html#a0494c9bfd3f584ab41e6dbeeaa0e6a19',1,'glfw3.h']]],
  ['glfw_5fno_5fapi',['GLFW_NO_API',['../glfw3_8h.html#a8f6dcdc968d214ff14779564f1389264',1,'glfw3.h']]],
  ['glfw_5fno_5freset_5fnotification',['GLFW_NO_RESET_NOTIFICATION',['../glfw3_8h.html#aee84a679230d205005e22487ff678a85',1,'glfw3.h']]],
  ['glfw_5fno_5frobustness',['GLFW_NO_ROBUSTNESS',['../glfw3_8h.html#a8b306cb27f5bb0d6d67c7356a0e0fc34',1,'glfw3.h']]],
  ['glfw_5fopengl_5fany_5fprofile',['GLFW_OPENGL_ANY_PROFILE',['../glfw3_8h.html#ad6f2335d6f21cc9bab96633b1c111d5f',1,'glfw3.h']]],
  ['glfw_5fopengl_5fapi',['GLFW_OPENGL_API',['../glfw3_8h.html#a01b3f66db266341425e9abee6b257db2',1,'glfw3.h']]],
  ['glfw_5fopengl_5fcompat_5fprofile',['GLFW_OPENGL_COMPAT_PROFILE',['../glfw3_8h.html#ac06b663d79c8fcf04669cc8fcc0b7670',1,'glfw3.h']]],
  ['glfw_5fopengl_5fcore_5fprofile',['GLFW_OPENGL_CORE_PROFILE',['../glfw3_8h.html#af094bb16da76f66ebceb19ee213b3de8',1,'glfw3.h']]],
  ['glfw_5fopengl_5fdebug_5fcontext',['GLFW_OPENGL_DEBUG_CONTEXT',['../glfw3_8h.html#a87ec2df0b915201e950ca42d5d0831e1',1,'glfw3.h']]],
  ['glfw_5fopengl_5fes_5fapi',['GLFW_OPENGL_ES_API',['../glfw3_8h.html#a28d9b3bc6c2a522d815c8e146595051f',1,'glfw3.h']]],
  ['glfw_5fopengl_5fforward_5fcompat',['GLFW_OPENGL_FORWARD_COMPAT',['../glfw3_8h.html#a13d24b12465da8b28985f46c8557925b',1,'glfw3.h']]],
  ['glfw_5fopengl_5fprofile',['GLFW_OPENGL_PROFILE',['../glfw3_8h.html#a44f3a6b4261fbe351e0b950b0f372e12',1,'glfw3.h']]],
  ['glfw_5fred_5fbits',['GLFW_RED_BITS',['../glfw3_8h.html#af78ed8e417dbcc1e354906cc2708c982',1,'glfw3.h']]],
  ['glfw_5frefresh_5frate',['GLFW_REFRESH_RATE',['../glfw3_8h.html#a0f20825e6e47ee8ba389024519682212',1,'glfw3.h']]],
  ['glfw_5frelease_5fbehavior_5fflush',['GLFW_RELEASE_BEHAVIOR_FLUSH',['../glfw3_8h.html#a999961d391db49cb4f949c1dece0e13b',1,'glfw3.h']]],
  ['glfw_5frelease_5fbehavior_5fnone',['GLFW_RELEASE_BEHAVIOR_NONE',['../glfw3_8h.html#afca09088eccacdce4b59036cfae349c5',1,'glfw3.h']]],
  ['glfw_5fresizable',['GLFW_RESIZABLE',['../glfw3_8h.html#adba13c7a1b3aa40831eb2beedbd5bd1d',1,'glfw3.h']]],
  ['glfw_5fsamples',['GLFW_SAMPLES',['../glfw3_8h.html#a2cdf86fdcb7722fb8829c4e201607535',1,'glfw3.h']]],
  ['glfw_5fsrgb_5fcapable',['GLFW_SRGB_CAPABLE',['../glfw3_8h.html#a444a8f00414a63220591f9fdb7b5642b',1,'glfw3.h']]],
  ['glfw_5fstencil_5fbits',['GLFW_STENCIL_BITS',['../glfw3_8h.html#a5339890a45a1fb38e93cb9fcc5fd069d',1,'glfw3.h']]],
  ['glfw_5fstereo',['GLFW_STEREO',['../glfw3_8h.html#a83d991efca02537e2d69969135b77b03',1,'glfw3.h']]],
  ['glfw_5fsticky_5fkeys',['GLFW_STICKY_KEYS',['../glfw3_8h.html#ae3bbe2315b7691ab088159eb6c9110fc',1,'glfw3.h']]],
  ['glfw_5fsticky_5fmouse_5fbuttons',['GLFW_STICKY_MOUSE_BUTTONS',['../glfw3_8h.html#a4d7ce8ce71030c3b04e2b78145bc59d1',1,'glfw3.h']]],
  ['glfw_5ftrue',['GLFW_TRUE',['../glfw3_8h.html#a2744fbb29b5631bb28802dbe0cf36eba',1,'glfw3.h']]],
  ['glfw_5fvisible',['GLFW_VISIBLE',['../glfw3_8h.html#afb3cdc45297e06d8f1eb13adc69ca6c4',1,'glfw3.h']]]
];

==> glfw-doc-3.3-2-armv6h.pkg.tar.xz: usr/share/doc/glfw/html/search/defines_0.js <==
var searchData=
[
  ['glapientry',['GLAPIENTRY',['../glfw3_8h.html#aa97755eb47e4bf2727ad45d610e18206',1,'glfw3.h']]],
  ['glfw_5fany_5frelease_5fbehavior',['GLFW_ANY_RELEASE_BEHAVIOR',['../glfw3_8h.html#a6b47d806f285efe9bfd7aeec667297ee',1,'glfw3.h']]],
  ['glfw_5fapientry_5fdefined',['GLFW_APIENTRY_DEFINED',['../glfw3_8h.html#a8a8538c5500308b4211844f2fb26c7b9',1,'glfw3.h']]],
  ['glfw_5fconnected',['GLFW_CONNECTED',['../glfw3_8h.html#abe11513fd1ffbee5bb9b173f06028b9e',1,'glfw3.h']]],
  ['glfw_5fcursor',['GLFW_CURSOR',['../glfw3_8h.html#aade31da5b884a84a7625c6b059b9132c',1,'glfw3.h']]],
  ['glfw_5fcursor_5fdisabled',['GLFW_CURSOR_DISABLED',['../glfw3_8h.html#a2315b99a329ce53e6a13a9d46fd5ca88',1,'glfw3.h']]],
  ['glfw_5fcursor_5fhidden',['GLFW_CURSOR_HIDDEN',['../glfw3_8h.html#ac4d5cb9d78de8573349c58763d53bf11',1,'glfw3.h']]],
  ['glfw_5fcursor_5fnormal',['GLFW_CURSOR_NORMAL',['../glfw3_8h.html#ae04dd25c8577e19fa8c97368561f6c68',1,'glfw3.h']]],
  ['glfw_5fdisconnected',['GLFW_DISCONNECTED',['../glfw3_8h.html#aab64b25921ef21d89252d6f0a71bfc32',1,'glfw3.h']]],
  ['glfw_5fdont_5fcare',['GLFW_DONT_CARE',['../glfw3_8h.html#a7a2edf2c18446833d27d07f1b7f3d571',1,'glfw3.h']]],
  ['glfw_5fegl_5fcontext_5fapi',['GLFW_EGL_CONTEXT_API',['../glfw3_8h.html#a03cf65c9ab01fc8b872ba58842c531c9',1,'glfw3.h']]],
  ['glfw_5flock_5fkey_5fmods',['GLFW_LOCK_KEY_MODS',['../glfw3_8h.html#a07b84de0b52143e1958f88a7d9105947',1,'glfw3.h']]],
  ['glfw_5flose_5fcontext_5fon_5freset',['GLFW_LOSE_CONTEXT_ON_RESET',['../glfw3_8h.html#aec1132f245143fc915b2f0995228564c',1,'glfw3.h']]],
  ['glfw_5fnative_5fcontext_5fapi',['GLFW_NATIVE_CONTEXT_API',['../glfw3_8h.html#a0494c9bfd3f584ab41e6dbeeaa0e6a19',1,'glfw3.h']]],
  ['glfw_5fno_5fapi',['GLFW_NO_API',['../glfw3_8h.html#a8f6dcdc968d214ff14779564f1389264',1,'glfw3.h']]],
  ['glfw_5fno_5freset_5fnotification',['GLFW_NO_RESET_NOTIFICATION',['../glfw3_8h.html#aee84a679230d205005e22487ff678a85',1,'glfw3.h']]],
  ['glfw_5fno_5frobustness',['GLFW_NO_ROBUSTNESS',['../glfw3_8h.html#a8b306cb27f5bb0d6d67c7356a0e0fc34',1,'glfw3.h']]],
  ['glfw_5fopengl_5fany_5fprofile',['GLFW_OPENGL_ANY_PROFILE',['../glfw3_8h.html#ad6f2335d6f21cc9bab96633b1c111d5f',1,'glfw3.h']]],
  ['glfw_5fopengl_5fapi',['GLFW_OPENGL_API',['../glfw3_8h.html#a01b3f66db266341425e9abee6b257db2',1,'glfw3.h']]],
  ['glfw_5fopengl_5fcompat_5fprofile',['GLFW_OPENGL_COMPAT_PROFILE',['../glfw3_8h.html#ac06b663d79c8fcf04669cc8fcc0b7670',1,'glfw3.h']]],
  ['glfw_5fopengl_5fcore_5fprofile',['GLFW_OPENGL_CORE_PROFILE',['../glfw3_8h.html#af094bb16da76f66ebceb19ee213b3de8',1,'glfw3.h']]],
  ['glfw_5fopengl_5fes_5fapi',['GLFW_OPENGL_ES_API',['../glfw3_8h.html#a28d9b3bc6c2a522d815c8e146595051f',1,'glfw3.h']]],
  ['glfw_5fosmesa_5fcontext_5fapi',['GLFW_OSMESA_CONTEXT_API',['../glfw3_8h.html#afd34a473af9fa81f317910ea371b19e3',1,'glfw3.h']]],
  ['glfw_5fraw_5fmouse_5fmotion',['GLFW_RAW_MOUSE_MOTION',['../glfw3_8h.html#aeeda1be76a44a1fc97c1282e06281fbb',1,'glfw3.h']]],
  ['glfw_5frelease_5fbehavior_5fflush',['GLFW_RELEASE_BEHAVIOR_FLUSH',['../glfw3_8h.html#a999961d391db49cb4f949c1dece0e13b',1,'glfw3.h']]],
  ['glfw_5frelease_5fbehavior_5fnone',['GLFW_RELEASE_BEHAVIOR_NONE',['../glfw3_8h.html#afca09088eccacdce4b59036cfae349c5',1,'glfw3.h']]],
  ['glfw_5fsticky_5fkeys',['GLFW_STICKY_KEYS',['../glfw3_8h.html#ae3bbe2315b7691ab088159eb6c9110fc',1,'glfw3.h']]],
  ['glfw_5fsticky_5fmouse_5fbuttons',['GLFW_STICKY_MOUSE_BUTTONS',['../glfw3_8h.html#a4d7ce8ce71030c3b04e2b78145bc59d1',1,'glfw3.h']]]
];
